Learn R Programming

r2social (version 1.1)

socialButtons: Customizable social icons

Description

For use in making buttons to share a page or connect to your social media

Usage

socialButtons(
  link,
  type = c("share", "connect"),
  image = NULL,
  text = NULL,
  plain = FALSE,
  position = c("left", "right", "inline"),
  text.color = "white",
  facebook = FALSE,
  linkedin = FALSE,
  x = FALSE,
  tumblr = FALSE,
  pinterest = FALSE,
  whatsapp = FALSE,
  reddit = FALSE,
  instagram = FALSE,
  blogger = FALSE,
  weibo = FALSE,
  tiktok = FALSE,
  vk = FALSE,
  baidu = FALSE,
  telegram = FALSE,
  youtube = FALSE,
  visit.us = FALSE,
  link.out = FALSE
)

Value

Social links button to be placed on pages

Arguments

link

link address to share

type

type of social button e.g. share or connect

image

image link for pinterest only

text

text link for x only

plain

logical. with or without background

position

position of buttons e.g "left","right","bottom","inline"

text.color

text color

facebook

share on Facebook

linkedin

share on Linkedin

x

share on Twitter

tumblr

share on Tumblr

pinterest

share on Pinterest

whatsapp

share on Whatsapp

reddit

share on Reddit

instagram

share on Instagram

blogger

share on Blogger

weibo

share on Weibo

tiktok

share on Tiktok

vk

share on VK or VKontakte

baidu

share on Baidu

telegram

share on Telegram

youtube

share on Youtube

visit.us

visit a direct link

link.out

hyperlink to a page

Examples for r2social

More examples and demo pages are located at this link - https://rpkg.net/package/r2social.

Examples

Run this code
# styled
socialButtons("https://shinyappstore.com/",facebook = TRUE)

# plain
socialButtons("https://shinyappstore.com/",plain=TRUE, linkedin = TRUE)

Run the code above in your browser using DataLab